CodeSystem

Struct CodeSystem 

pub struct CodeSystem {
Show 34 fields pub id: Option<String>, pub meta: Option<Meta>, pub implicit_rules: Option<Uri>, pub language: Option<Code>, pub text: Option<Narrative>, pub contained: Option<Vec<Resource>>, pub extension: Option<Vec<Extension>>, pub modifier_extension: Option<Vec<Extension>>, pub url: Option<Uri>, pub identifier: Option<Vec<Identifier>>, pub version: Option<String>, pub name: Option<String>, pub title: Option<String>, pub status: Code, pub experimental: Option<Boolean>, pub date: Option<DateTime>, pub publisher: Option<String>, pub contact: Option<Vec<ContactDetail>>, pub description: Option<Markdown>, pub use_context: Option<Vec<UsageContext>>, pub jurisdiction: Option<Vec<CodeableConcept>>, pub purpose: Option<Markdown>, pub copyright: Option<Markdown>, pub case_sensitive: Option<Boolean>, pub value_set: Option<Canonical>, pub hierarchy_meaning: Option<Code>, pub compositional: Option<Boolean>, pub version_needed: Option<Boolean>, pub content: Code, pub supplements: Option<Canonical>, pub count: Option<UnsignedInt>, pub filter: Option<Vec<CodeSystemFilter>>, pub property: Option<Vec<CodeSystemProperty>>, pub concept: Option<Vec<CodeSystemConcept>>,
}
FHIR CodeSystem type

The CodeSystem resource is used to declare the existence of and describe a code system or code system supplement and its key properties, and optionally define a part or all of its content.

Type: Resource type

Base type: http://hl7.org/fhir/StructureDefinition/DomainResource

Status: active

FHIR Version: 4.0.1

See: CodeSystem

Fields

id: Option<String>

Logical id of this artifact

The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.

Implementation Notes

The only time that a resource does not have an id is when it is being submitted to the server using a create operation.

Cardinality: Optional (0..1)

Special Semantics

  • Included in summary
meta: Option<Meta>

Metadata about the resource

The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.

Cardinality: Optional (0..1)

Special Semantics

  • Included in summary

Constraints

  • ele-1: All FHIR elements must have a @value or children (error) Expression: hasValue() or (children().count() > id.count())
implicit_rules: Option<Uri>

A set of rules under which this content was created

A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.

Implementation Notes

Asserting this rule set restricts the content to be only understood by a limited set of trading partners. This inherently limits the usefulness of the data in the long term. However, the existing health eco-system is highly fractured, and not yet ready to define, collect, and exchange data in a generally computable sense. Wherever possible, implementers and/or specification writers should avoid using this element. Often, when used, the URL is a reference to an implementation guide that defines these special rules as part of it’s narrative along with other profiles, value sets, etc.

Cardinality: Optional (0..1)

Special Semantics

  • Modifier element - This element is labeled as a modifier because the implicit rules may provide additional knowledge about the resource that modifies it’s meaning or interpretation
  • Included in summary

Constraints

  • ele-1: All FHIR elements must have a @value or children (error) Expression: hasValue() or (children().count() > id.count())
language: Option<Code>

Language of the resource content

The base language in which the resource is written.

Implementation Notes

Language is provided to support indexing and accessibility (typically, services such as text to speech use the language tag). The html language tag in the narrative applies to the narrative. The language tag on the resource may be used to specify the language of other presentations generated from the data in the resource. Not all the content has to be in the base language. The Resource.language should not be assumed to apply to the narrative automatically. If a language is specified, it should it also be specified on the div element in the html (see rules in HTML5 for information about the relationship between xml:lang and the html lang attribute).

Cardinality: Optional (0..1)

Constraints

  • ele-1: All FHIR elements must have a @value or children (error) Expression: hasValue() or (children().count() > id.count())

Binding

  • Strength: preferred
  • Description: A human language.
  • ValueSet: http://hl7.org/fhir/ValueSet/languages
text: Option<Narrative>

Text summary of the resource, for human interpretation

A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it “clinically safe” for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.

Implementation Notes

Contained resources do not have narrative. Resources that are not contained SHOULD have a narrative. In some cases, a resource may only have text with little or no additional discrete data (as long as all minOccurs=1 elements are satisfied). This may be necessary for data from legacy systems where information is captured as a “text blob” or where text is additionally entered raw or narrated and encoded information is added later.

Cardinality: Optional (0..1)

Constraints

  • ele-1: All FHIR elements must have a @value or children (error) Expression: hasValue() or (children().count() > id.count())

Aliases

narrative, html, xhtml, display

contained: Option<Vec<Resource>>

Contained, inline Resources

These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope.

Implementation Notes

This should never be done when the content can be identified properly, as once identification is lost, it is extremely difficult (and context dependent) to restore it again. Contained resources may have profiles and tags In their meta elements, but SHALL NOT have security labels.

Cardinality: Optional, Multiple (0..*)

Aliases

inline resources, anonymous resources, contained resources

extension: Option<Vec<Extension>>

Additional content defined by implementations

May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.

Implementation Notes

There can be no stigma associated with the use of extensions by any application, project, or standard - regardless of the institution or jurisdiction that uses or defines the extensions. The use of extensions is what allows the FHIR specification to retain a core level of simplicity for everyone.

Cardinality: Optional, Multiple (0..*)

Constraints

  • ele-1: All FHIR elements must have a @value or children (error) Expression: hasValue() or (children().count() > id.count())
  • ext-1: Must have either extensions or value[x], not both (error) Expression: extension.exists() != value.exists()

Aliases

extensions, user content

modifier_extension: Option<Vec<Extension>>

Extensions that cannot be ignored

May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element’s descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.

Modifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself).

Requirements

Modifier extensions allow for extensions that cannot be safely ignored to be clearly distinguished from the vast majority of extensions which can be safely ignored. This promotes interoperability by eliminating the need for implementers to prohibit the presence of extensions. For further information, see the definition of modifier extensions.

Implementation Notes

There can be no stigma associated with the use of extensions by any application, project, or standard - regardless of the institution or jurisdiction that uses or defines the extensions. The use of extensions is what allows the FHIR specification to retain a core level of simplicity for everyone.

Cardinality: Optional, Multiple (0..*)

Special Semantics

  • Modifier element - Modifier extensions are expected to modify the meaning or interpretation of the resource that contains them

Constraints

  • ele-1: All FHIR elements must have a @value or children (error) Expression: hasValue() or (children().count() > id.count())
  • ext-1: Must have either extensions or value[x], not both (error) Expression: extension.exists() != value.exists()

Aliases

extensions, user content

url: Option<Uri>

Canonical identifier for this code system, represented as a URI (globally unique) (Coding.system)

An absolute URI that is used to identify this code system when it is referenced in a specification, model, design or an instance; also called its canonical identifier. This SHOULD be globally unique and SHOULD be a literal address at which at which an authoritative instance of this code system is (or will be) published. This URL can be the target of a canonical reference. It SHALL remain the same when the code system is stored on different servers. This is used in Coding.system.

Requirements

Allows the code system to be referenced by a single globally unique identifier.

Implementation Notes

Can be a urn:uuid: or a urn:oid: but real http: addresses are preferred. Multiple instances may share the same URL if they have a distinct version.

The determination of when to create a new version of a resource (same url, new version) vs. defining a new artifact is up to the author. Considerations for making this decision are found in Technical and Business Versions.

In some cases, the resource can no longer be found at the stated url, but the url itself cannot change. Implementations can use the meta.source element to indicate where the current master source of the resource can be found.

Cardinality: Optional (0..1)

Special Semantics

  • Included in summary

Constraints

  • ele-1: All FHIR elements must have a @value or children (error) Expression: hasValue() or (children().count() > id.count())
identifier: Option<Vec<Identifier>>

Additional identifier for the code system (business identifier)

A formal identifier that is used to identify this code system when it is represented in other formats, or referenced in a specification, model, design or an instance.

Requirements

Allows externally provided and/or usable business identifiers to be easily associated with the module.

Implementation Notes

Typically, this is used for identifiers that can go in an HL7 V3 II (instance identifier) data type, and can then identify this code system outside of FHIR, where it is not possible to use the logical URI. Note that HL7 defines at least three identifiers for many of its code systems - the FHIR canonical URL, the OID and the V2 Table 0396 mnemonic code.

Cardinality: Optional, Multiple (0..*)

Special Semantics

  • Included in summary

Constraints

  • ele-1: All FHIR elements must have a @value or children (error) Expression: hasValue() or (children().count() > id.count())
version: Option<String>

Business version of the code system (Coding.version)

The identifier that is used to identify this version of the code system when it is referenced in a specification, model, design or instance. This is an arbitrary value managed by the code system author and is not expected to be globally unique. For example, it might be a timestamp (e.g. yyyymmdd) if a managed version is not available. There is also no expectation that versions can be placed in a lexicographical sequence. This is used in Coding.version.

Implementation Notes

There may be different code system instances that have the same identifier but different versions. The version can be appended to the url in a reference to allow a reference to a particular business version of the code system with the format [url]|[version].

Cardinality: Optional (0..1)

Special Semantics

  • Included in summary

Constraints

  • ele-1: All FHIR elements must have a @value or children (error) Expression: hasValue() or (children().count() > id.count())
name: Option<String>

Name for this code system (computer friendly)

A natural language name identifying the code system. This name should be usable as an identifier for the module by machine processing applications such as code generation.

Requirements

Support human navigation and code generation.

Implementation Notes

The name is not expected to be globally unique. The name should be a simple alphanumeric type name to ensure that it is machine-processing friendly.

Cardinality: Optional (0..1)

Special Semantics

  • Included in summary

Constraints

  • ele-1: All FHIR elements must have a @value or children (error) Expression: hasValue() or (children().count() > id.count())

Conditions

Used when: inv-0

title: Option<String>

Name for this code system (human friendly)

A short, descriptive, user-friendly title for the code system.

Implementation Notes

This name does not need to be machine-processing friendly and may contain punctuation, white-space, etc.

Cardinality: Optional (0..1)

Special Semantics

  • Included in summary

Constraints

  • ele-1: All FHIR elements must have a @value or children (error) Expression: hasValue() or (children().count() > id.count())
status: Code

draft | active | retired | unknown

The date (and optionally time) when the code system resource was created or revised.

Implementation Notes

Allows filtering of code systems that are appropriate for use versus not.

Cardinality: Required (1..1)

Special Semantics

  • Modifier element - This is labeled as “Is Modifier” because applications should not use a retired {{title}} without due consideration
  • Included in summary

Constraints

  • ele-1: All FHIR elements must have a @value or children (error) Expression: hasValue() or (children().count() > id.count())

Binding

  • Strength: required
  • Description: The lifecycle status of an artifact.
  • ValueSet: http://hl7.org/fhir/ValueSet/publication-status|4.0.1
experimental: Option<Boolean>

For testing purposes, not real usage

A Boolean value to indicate that this code system is authored for testing purposes (or education/evaluation/marketing) and is not intended to be used for genuine usage.

Requirements

Enables experimental content to be developed following the same lifecycle that would be used for a production-level code system.

Implementation Notes

Allows filtering of code systems that are appropriate for use versus not.

Cardinality: Optional (0..1)

Special Semantics

  • Included in summary

Constraints

  • ele-1: All FHIR elements must have a @value or children (error) Expression: hasValue() or (children().count() > id.count())
date: Option<DateTime>

Date last changed

The date (and optionally time) when the code system was published. The date must change when the business version changes and it must change if the status code changes. In addition, it should change when the substantive content of the code system changes.

Implementation Notes

Note that this is not the same as the resource last-modified-date, since the resource may be a secondary representation of the code system. Additional specific dates may be added as extensions or be found by consulting Provenances associated with past versions of the resource.

Cardinality: Optional (0..1)

Special Semantics

  • Included in summary

Constraints

  • ele-1: All FHIR elements must have a @value or children (error) Expression: hasValue() or (children().count() > id.count())

Aliases

Revision Date

publisher: Option<String>

Name of the publisher (organization or individual)

The name of the organization or individual that published the code system.

Requirements

Helps establish the “authority/credibility” of the code system. May also allow for contact.

Implementation Notes

Usually an organization but may be an individual. The publisher (or steward) of the code system is the organization or individual primarily responsible for the maintenance and upkeep of the code system. This is not necessarily the same individual or organization that developed and initially authored the content. The publisher is the primary point of contact for questions or issues with the code system. This item SHOULD be populated unless the information is available from context.

Cardinality: Optional (0..1)

Special Semantics

  • Included in summary

Constraints

  • ele-1: All FHIR elements must have a @value or children (error) Expression: hasValue() or (children().count() > id.count())
contact: Option<Vec<ContactDetail>>

Contact details for the publisher

Contact details to assist a user in finding and communicating with the publisher.

Implementation Notes

May be a web site, an email address, a telephone number, etc.

Cardinality: Optional, Multiple (0..*)

Special Semantics

  • Included in summary

Constraints

  • ele-1: All FHIR elements must have a @value or children (error) Expression: hasValue() or (children().count() > id.count())
description: Option<Markdown>

Natural language description of the code system

A free text natural language description of the code system from a consumer’s perspective.

Implementation Notes

This description can be used to capture details such as why the code system was built, comments about misuse, instructions for clinical use and interpretation, literature references, examples from the paper world, etc. It is not a rendering of the code system as conveyed in the ‘text’ field of the resource itself. This item SHOULD be populated unless the information is available from context (e.g. the language of the code system is presumed to be the predominant language in the place the code system was created).

Cardinality: Optional (0..1)

Constraints

  • ele-1: All FHIR elements must have a @value or children (error) Expression: hasValue() or (children().count() > id.count())

Aliases

Scope, Purpose

use_context: Option<Vec<UsageContext>>

The context that the content is intended to support

The content was developed with a focus and intent of supporting the contexts that are listed. These contexts may be general categories (gender, age, …) or may be references to specific programs (insurance plans, studies, …) and may be used to assist with indexing and searching for appropriate code system instances.

Requirements

Assist in searching for appropriate content.

Implementation Notes

When multiple useContexts are specified, there is no expectation that all or any of the contexts apply.

Cardinality: Optional, Multiple (0..*)

Special Semantics

  • Included in summary

Constraints

  • ele-1: All FHIR elements must have a @value or children (error) Expression: hasValue() or (children().count() > id.count())
jurisdiction: Option<Vec<CodeableConcept>>

Intended jurisdiction for code system (if applicable)

A legal or geographic region in which the code system is intended to be used.

Implementation Notes

It may be possible for the code system to be used in jurisdictions other than those for which it was originally designed or intended.

Cardinality: Optional, Multiple (0..*)

Special Semantics

  • Included in summary

Constraints

  • ele-1: All FHIR elements must have a @value or children (error) Expression: hasValue() or (children().count() > id.count())

Binding

  • Strength: extensible
  • Description: Countries and regions within which this artifact is targeted for use.
  • ValueSet: http://hl7.org/fhir/ValueSet/jurisdiction
purpose: Option<Markdown>

Why this code system is defined

Explanation of why this code system is needed and why it has been designed as it has.

Implementation Notes

This element does not describe the usage of the code system. Instead, it provides traceability of ’‘why’’ the resource is either needed or ’‘why’’ it is defined as it is. This may be used to point to source materials or specifications that drove the structure of this code system.

Cardinality: Optional (0..1)

Constraints

  • ele-1: All FHIR elements must have a @value or children (error) Expression: hasValue() or (children().count() > id.count())
copyright: Option<Markdown>

Use and/or publishing restrictions

A copyright statement relating to the code system and/or its contents. Copyright statements are generally legal restrictions on the use and publishing of the code system.

Requirements

Consumers must be able to determine any legal restrictions on the use of the code system and/or its content.

Implementation Notes

… Sometimes, the copyright differs between the code system and the codes that are included. The copyright statement should clearly differentiate between these when required.

Cardinality: Optional (0..1)

Constraints

  • ele-1: All FHIR elements must have a @value or children (error) Expression: hasValue() or (children().count() > id.count())

Aliases

License, Restrictions

case_sensitive: Option<Boolean>

If code comparison is case sensitive

If code comparison is case sensitive when codes within this system are compared to each other.

Implementation Notes

If this value is missing, then it is not specified whether a code system is case sensitive or not. When the rule is not known, Postel’s law should be followed: produce codes with the correct case, and accept codes in any case. This element is primarily provided to support validation software.

Cardinality: Optional (0..1)

Special Semantics

  • Included in summary

Constraints

  • ele-1: All FHIR elements must have a @value or children (error) Expression: hasValue() or (children().count() > id.count())
value_set: Option<Canonical>

Canonical reference to the value set with entire code system

Canonical reference to the value set that contains the entire code system.

Implementation Notes

The definition of the value set SHALL include all codes from this code system and only codes from this code system, and it SHALL be immutable.

Cardinality: Optional (0..1)

Special Semantics

  • Included in summary

Constraints

  • ele-1: All FHIR elements must have a @value or children (error) Expression: hasValue() or (children().count() > id.count())
hierarchy_meaning: Option<Code>

grouped-by | is-a | part-of | classified-with

The meaning of the hierarchy of concepts as represented in this resource.

Implementation Notes

Note that other representations might have a different hierarchy or none at all, and represent the information using properties.

Cardinality: Optional (0..1)

Special Semantics

  • Included in summary

Constraints

  • ele-1: All FHIR elements must have a @value or children (error) Expression: hasValue() or (children().count() > id.count())

Binding

  • Strength: required
  • Description: The meaning of the hierarchy of concepts in a code system.
  • ValueSet: http://hl7.org/fhir/ValueSet/codesystem-hierarchy-meaning|4.0.1
compositional: Option<Boolean>

If code system defines a compositional grammar

The code system defines a compositional (post-coordination) grammar.

Implementation Notes

Note that the code system resource does not define what the compositional grammar is, only whether or not there is one.

Cardinality: Optional (0..1)

Special Semantics

  • Included in summary

Constraints

  • ele-1: All FHIR elements must have a @value or children (error) Expression: hasValue() or (children().count() > id.count())

Aliases

grammar

version_needed: Option<Boolean>

If definitions are not stable

This flag is used to signify that the code system does not commit to concept permanence across versions. If true, a version must be specified when referencing this code system.

Implementation Notes

Best practice is that code systems do not redefine concepts, or that if concepts are redefined, a new code system definition is created. But this is not always possible, so some code systems may be defined as ‘versionNeeded’.

Most code systems occasionally refine the displays defined for concepts between versions. Contexts in which the concept display values are validated may require that the version be specified for some code systems irrespective of the value of this property.

Cardinality: Optional (0..1)

Special Semantics

  • Included in summary

Constraints

  • ele-1: All FHIR elements must have a @value or children (error) Expression: hasValue() or (children().count() > id.count())
content: Code

not-present | example | fragment | complete | supplement

The extent of the content of the code system (the concepts and codes it defines) are represented in this resource instance.

Cardinality: Required (1..1)

Special Semantics

  • Included in summary

Constraints

  • ele-1: All FHIR elements must have a @value or children (error) Expression: hasValue() or (children().count() > id.count())

Binding

  • Strength: required
  • Description: The extent of the content of the code system (the concepts and codes it defines) are represented in a code system resource.
  • ValueSet: http://hl7.org/fhir/ValueSet/codesystem-content-mode|4.0.1
supplements: Option<Canonical>

Canonical URL of Code System this adds designations and properties to

The canonical URL of the code system that this code system supplement is adding designations and properties to.

Implementation Notes

The most common use of a code system supplement is to add additional language support.

Cardinality: Optional (0..1)

Special Semantics

  • Included in summary

Constraints

  • ele-1: All FHIR elements must have a @value or children (error) Expression: hasValue() or (children().count() > id.count())
count: Option<UnsignedInt>

Total concepts in the code system

The total number of concepts defined by the code system. Where the code system has a compositional grammar, the basis of this count is defined by the system steward.

Implementation Notes

The count of concepts defined in this resource cannot be more than this value but may be less for several reasons - see the content element.

Cardinality: Optional (0..1)

Special Semantics

  • Included in summary

Constraints

  • ele-1: All FHIR elements must have a @value or children (error) Expression: hasValue() or (children().count() > id.count())
filter: Option<Vec<CodeSystemFilter>>

Filter that can be used in a value set

A filter that can be used in a value set compose statement when selecting concepts using a filter.

Implementation Notes

Note that filters defined in code systems usually require custom code on the part of any terminology engine that will make them available for use in value set filters. For this reason, they are generally only seen in high value published terminologies.

Cardinality: Optional, Multiple (0..*)

Special Semantics

  • Included in summary

Constraints

  • ele-1: All FHIR elements must have a @value or children (error) Expression: hasValue() or (children().count() > id.count())
property: Option<Vec<CodeSystemProperty>>

Additional information supplied about each concept

A property defines an additional slot through which additional information can be provided about a concept.

Cardinality: Optional, Multiple (0..*)

Special Semantics

  • Included in summary

Constraints

  • ele-1: All FHIR elements must have a @value or children (error) Expression: hasValue() or (children().count() > id.count())
concept: Option<Vec<CodeSystemConcept>>

Concepts in the code system

Concepts that are in the code system. The concept definitions are inherently hierarchical, but the definitions must be consulted to determine what the meanings of the hierarchical relationships are.

Implementation Notes

If this is empty, it means that the code system resource does not represent the content of the code system.

Cardinality: Optional, Multiple (0..*)

Constraints

  • ele-1: All FHIR elements must have a @value or children (error) Expression: hasValue() or (children().count() > id.count())